/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "alarm_dbus.h"
#include "aul_fake.h"
#include "cynara_fake.h"
#include "gio_fake.h"
#include "glib_fake.h"
#include "mock.h"
#include "notification_fake.h"

DEFINE_FFF_GLOBALS;

/* gio.h */
DEFINE_FAKE_VALUE_FUNC(GDBusConnection*, g_bus_get_sync,
		GBusType, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(GDBusProxy*, g_dbus_proxy_new_sync,
		GDBusConnection*, GDBusProxyFlags, GDBusInterfaceInfo*,
		const gchar*, const gchar*, const gchar*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(GDBusNodeInfo*, g_dbus_node_info_new_for_xml,
		const gchar*, GError**);
DEFINE_FAKE_VALUE_FUNC(guint, g_bus_own_name_on_connection, GDBusConnection*,
    const gchar*, GBusNameOwnerFlags,GBusNameAcquiredCallback,
    GBusNameLostCallback, gpointer, GDestroyNotify);
DEFINE_FAKE_VALUE_FUNC(guint, g_dbus_connection_register_object,
    GDBusConnection*, const gchar*, GDBusInterfaceInfo*,
    const GDBusInterfaceVTable*, gpointer, GDestroyNotify, GError**);
DEFINE_FAKE_VOID_FUNC(g_dbus_method_invocation_return_value,
    GDBusMethodInvocation*, GVariant*);
DEFINE_FAKE_VOID_FUNC(g_bus_unown_name, guint);
DEFINE_FAKE_VALUE_FUNC(gboolean, g_dbus_connection_emit_signal,
    GDBusConnection*, const gchar*, const gchar*, const gchar*, const gchar*,
    GVariant*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, g_dbus_connection_flush_sync,
    GDBusConnection*, GCancellable*, GError**);
DEFINE_FAKE_VOID_FUNC(g_dbus_node_info_unref, GDBusNodeInfo*);
DEFINE_FAKE_VALUE_FUNC(guint, g_dbus_connection_signal_subscribe,
		GDBusConnection*, const gchar*, const gchar*, const gchar*, const gchar*,
		const gchar*, GDBusSignalFlags, GDBusSignalCallback, gpointer,
		GDestroyNotify);
DEFINE_FAKE_VALUE_FUNC(gboolean, g_dbus_interface_skeleton_export,
    GDBusInterfaceSkeleton*, GDBusConnection*, const gchar*, GError**);

/* alarm_dbus.h */
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_info_sync,
    AlarmManager*, gint, gint*, gint*, gint*, gint*, gint*, gint*, gint*, gint*, gint*, gint*,
    gint*, gint*, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_create_appsvc_sync,
    AlarmManager*, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint,
    gint, gint, gint, const char*, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_appsvc_info_sync,
    AlarmManager*, gint, gchar**, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_create_noti_sync,
    AlarmManager*, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint,
    gint, gint, gint, const char*, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_noti_info_sync,
    AlarmManager*, gint, gchar**, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_set_rtc_time_sync, AlarmManager*, gint, gint, gint, gint, gint, gint,  gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_delete_sync, AlarmManager*, gint, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_delete_all_sync, AlarmManager*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_number_of_ids_sync, AlarmManager*, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_list_of_ids_sync, AlarmManager*, gint, GVariant**, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_next_duetime_sync, AlarmManager*, gint, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_create_periodic_sync, AlarmManager*, const gchar*, const gchar*, gint, gint, gint, gint*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_set_time_sync, AlarmManager*, gint, gint*, GCancellable*, GError**);
DEFINE_FAKE_VOID_FUNC(alarm_manager_call_alarm_set_time, AlarmManager*, gint, GCancellable*, GAsyncReadyCallback, gpointer);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_set_timezone_sync, AlarmManager*, const char*, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_set_time_with_propagation_delay_sync, AlarmManager*, guint, guint, guint, guint, gint*, GCancellable*, GError**);
DEFINE_FAKE_VOID_FUNC(alarm_manager_call_alarm_set_time_with_propagation_delay, AlarmManager*, guint, guint, guint, guint, GCancellable*, GAsyncReadyCallback, gpointer);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_update_sync, AlarmManager*, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_set_global_sync, AlarmManager*, gint, gboolean, gint*, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(gboolean, alarm_manager_call_alarm_get_global_sync, AlarmManager*, gint, gboolean*, gint*, GCancellable*, GError**);

/* glib_fake.h */
DEFINE_FAKE_VALUE_FUNC(GVariant*, g_dbus_connection_call_sync, GDBusConnection*,
		const gchar*, const gchar*, const gchar*, const gchar*, GVariant*,
		const GVariantType*, GDBusCallFlags, gint, GCancellable*, GError**);
DEFINE_FAKE_VALUE_FUNC(const gchar*, g_dbus_method_invocation_get_sender, GDBusMethodInvocation*);
DEFINE_FAKE_VOID_FUNC3_VARARG(g_variant_get, GVariant*, const gchar*, ...);
DEFINE_FAKE_VALUE_FUNC3_VARARG(gboolean, g_variant_iter_loop, GVariantIter*, const gchar*, ...);
DEFINE_FAKE_VOID_FUNC(g_variant_iter_free, GVariantIter*);
DEFINE_FAKE_VOID_FUNC(g_variant_unref, GVariant*);
DEFINE_FAKE_VALUE_FUNC2_VARARG(GVariant*, g_variant_new, const gchar*, ...);
DEFINE_FAKE_VALUE_FUNC(gpointer, g_hash_table_lookup, GHashTable*, gconstpointer);
DEFINE_FAKE_VALUE_FUNC(guint, g_hash_table_foreach_remove, GHashTable*,
		GHRFunc, gpointer);
DEFINE_FAKE_VALUE_FUNC(gboolean, g_hash_table_insert, GHashTable*,
		gpointer, gpointer);

/* aul.h */
DEFINE_FAKE_VALUE_FUNC(int, aul_app_get_appid_bypid, int, char*, int);

/* notification.h */
DEFINE_FAKE_VALUE_FUNC(notification_h, notification_create, notification_type_e);
DEFINE_FAKE_VALUE_FUNC(GVariant*, notification_ipc_make_gvariant_from_noti, notification_h, bool);

/* cynara_fake.h */
DEFINE_FAKE_VALUE_FUNC(int, cynara_initialize, cynara**,
		const cynara_configuration*);
DEFINE_FAKE_VALUE_FUNC(int, cynara_creds_gdbus_get_user, GDBusConnection*,
		const gchar*, enum cynara_user_creds, gchar **);
DEFINE_FAKE_VALUE_FUNC(int, cynara_creds_gdbus_get_client, GDBusConnection*,
		const gchar*, enum cynara_client_creds, gchar **);
DEFINE_FAKE_VALUE_FUNC(char*, cynara_session_from_pid, pid_t);
DEFINE_FAKE_VALUE_FUNC(int, cynara_check, cynara*, const char*, const char*,
		const char*, const char*);

